@@ -1,12 +1,11 @@
 import re
 from typing import ClassVar
-from typing_extensions import override
 
 from httpx import AsyncClient
 import msgspec
 
 from ..download import YTDLP_DOWNLOADER
-from .base import BaseParser, Platform, PlatformEnum, pconfig
+from .base import BaseParser, Platform, PlatformEnum, handle, pconfig
 from .cookie import save_cookies_with_netscape
 
 
@@ -14,41 +13,38 @@ class YouTubeParser(BaseParser):
     # 平台信息
     platform: ClassVar[Platform] = Platform(name=PlatformEnum.YOUTUBE, display_name="油管")
 
-    # URL 正则表达式模式（keyword, pattern）
-    patterns: ClassVar[list[tuple[str, str]]] = [
-        ("youtube.com", r"https?://(?:www\.)?youtube\.com/(?:watch|shorts)(?:/[A-Za-z\d_\-]+|\?v=[A-Za-z\d_\-]+)"),
-        ("youtu.be", r"https?://(?:www\.)?youtu\.be/[A-Za-z\d\._\?%&\+\-=/#]+"),
-    ]
-
     def __init__(self):
         super().__init__()
         self.cookies_file = pconfig.config_dir / "ytb_cookies.txt"
         if pconfig.ytb_ck:
-            save_cookies_with_netscape(pconfig.ytb_ck, self.cookies_file, "youtube.com")
+            save_cookies_with_netscape(
+                pconfig.ytb_ck,
+                self.cookies_file,
+                "youtube.com",
+            )
 
-    @override
-    async def parse(self, keyword: str, searched: re.Match[str]):
-        """解析 URL 获取内容信息并下载资源
+    @handle("youtu.be", r"https?://(?:www\.)?youtu\.be/[A-Za-z\d\._\?%&\+\-=/#]+")
+    @handle("youtube.com", r"https?://(?:www\.)?youtube\.com/(?:watch|shorts)(?:/[A-Za-z\d_\-]+|\?v=[A-Za-z\d_\-]+)")
+    async def _parse_video(self, searched: re.Match[str]):
+        return await self.parse_video(searched)
 
-        Args:
-            keyword: 关键词
-            searched: 正则表达式匹配对象，由平台对应的模式匹配得到
-
-        Returns:
-            ParseResult: 解析结果（已下载资源，包含 Path）
-
-        Raises:
-            ParseException: 解析失败时抛出
-        """
+    async def parse_video(self, searched: re.Match[str]):
         # 从匹配对象中获取原始URL
         url = searched.group(0)
 
         video_info = await YTDLP_DOWNLOADER.extract_video_info(url, self.cookies_file)
         author = await self._fetch_author_info(video_info.channel_id)
+
         contents = []
         if video_info.duration <= pconfig.duration_maximum:
             video = YTDLP_DOWNLOADER.download_video(url, self.cookies_file)
-            contents.append(self.create_video_content(video, video_info.thumbnail, video_info.duration))
+            contents.append(
+                self.create_video_content(
+                    video,
+                    video_info.thumbnail,
+                    video_info.duration,
+                )
+            )
         else:
             contents.extend(self.create_image_contents([video_info.thumbnail]))
 
@@ -59,7 +55,7 @@ class YouTubeParser(BaseParser):
             timestamp=video_info.timestamp,
         )
 
-    async def parse_url_as_audio(self, url: str):
+    async def parse_audio(self, url: str):
         """解析 YouTube URL 并标记为音频下载
 
         Args:
