@@ -1,9 +1,9 @@
-from collections.abc import Callable, Coroutine
+from collections.abc import Awaitable, Callable
 from dataclasses import dataclass
 from functools import lru_cache, wraps
 from io import BytesIO
 from pathlib import Path
-from typing import Any, ClassVar, ParamSpec, TypeVar
+from typing import ClassVar, ParamSpec, TypeVar
 from typing_extensions import override
 
 from nonebot import logger
@@ -11,7 +11,7 @@ from PIL import Image, ImageDraw, ImageFont
 from pilmoji import EmojiCDNSource, EmojiStyle, Pilmoji
 
 from ..config import pconfig
-from ..parsers.data import GraphicsContent
+from ..parsers import GraphicsContent
 from .base import ImageRenderer, ParseResult
 
 # 定义类型变量
@@ -39,8 +39,8 @@ def suppress_exception(
 
 
 def suppress_exception_async(
-    func: Callable[P, Coroutine[Any, Any, T]],
-) -> Callable[P, Coroutine[Any, Any, T | None]]:
+    func: Callable[P, Awaitable[T]],
+) -> Callable[P, Awaitable[T | None]]:
     """装饰器：捕获所有异常并返回 None"""
 
     @wraps(func)
@@ -322,7 +322,8 @@ class CommonRenderer(ImageRenderer):
     @classmethod
     def _load_video_button(cls):
         """预加载视频按钮"""
-        cls.video_button_image: PILImage = Image.open(cls.DEFAULT_VIDEO_BUTTON_PATH).convert("RGBA")
+        with Image.open(cls.DEFAULT_VIDEO_BUTTON_PATH) as img:
+            cls.video_button_image: PILImage = img.convert("RGBA")
 
         # 设置透明度为 30%
         alpha = cls.video_button_image.split()[-1]  # 获取 alpha 通道
@@ -332,13 +333,14 @@ class CommonRenderer(ImageRenderer):
     @classmethod
     def _load_platform_logos(cls):
         """预加载平台 logo"""
-        cls.platform_logos: dict[str, PILImage] = {}
         from ..constants import PlatformEnum
 
+        cls.platform_logos: dict[str, PILImage] = {}
         for platform_name in PlatformEnum:
             logo_path = cls.RESOURCES_DIR / f"{platform_name}.png"
             if logo_path.exists():
-                cls.platform_logos[str(platform_name)] = Image.open(logo_path)
+                with Image.open(logo_path) as img:
+                    cls.platform_logos[str(platform_name)] = img.convert("RGBA")
 
     @classmethod
     async def text(
